Offset

Trait Offset 

pub trait Offset {
    // Required method
    fn offset_path(&self) -> Result<Path>;
}
A trait for types that can offset a path.

This trait provides a generic interface for path offsetting algorithms. Implementors of this trait are expected to provide an implementation for the offset_path method.

Required Methods

fn offset_path(&self) -> Result<Path>

Offsets the given path.

Arguments
  • path - A reference to the Path to be offset.
Returns

A Result containing the offset Path or an error.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors