Module conversions

Module conversions 

Handles conversions between this crate’s path types and those from other geometry libraries.

This module and its submodules provide From trait implementations to facilitate interoperability. For example, converting a lyon::path::Path into this crate’s path_offset::path::Path and vice-versa.

Currently supported libraries:

Modules

cavalier_contours
Provides conversions to and from cavalier_contours path types.
flo_curves
Provides conversions to and from flo_curves path types.
lyon
Provides conversions from lyon::path::Path.