Module cavalier_contours

Module cavalier_contours 

Provides conversions to and from cavalier_contours path types.

This module is intended to house From trait implementations that allow for seamless interoperability between path-offset’s path representation and the path types used by the cavalier_contours library.