Provides conversions from lyon::path::Path.
This module facilitates the direct use of lyon paths within this crate
by providing a From implementation.
Provides conversions from lyon::path::Path.
This module facilitates the direct use of lyon paths within this crate
by providing a From implementation.