Module offset

Module offset 

Defines the Offset trait for path offsetting.

This module provides the central Offset trait, which defines the contract for path offsetting algorithms. It also includes modules for different offsetting implementations, such as cavalier_contours and flo_curves.

Modules

cavalier_contours
flo_curves
Implements path offsetting using the flo_curves library.

Traits

Offset
A trait for types that can offset a path.