pub trait Offset {
// Required method
fn offset_path(&self) -> Result<Path>;
}Expand description
A trait for types that can offset a path.
This trait provides a generic interface for path offsetting algorithms.
Implementors of this trait are expected to provide an implementation for the offset_path method.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".